audplot
=======

.. automodule:: audplot

.. autosummary::
    :toctree:
    :nosignatures:

    cepstrum
    confusion_matrix
    detection_error_tradeoff
    distribution
    human_format
    scatter
    series
    signal
    spectrum
    waveform
